#!/usr/bin/python
# -*- coding: utf-8 -*-
import random
import time

from logger import Logger
from singleton import Singleton
import bottle
import json
import os


class Mobile:
    __metaclass__ = Singleton

    def __init__(self):
        self.log = Logger()
        self.cases = {}

    def registerRoutes(self, servicestub):
        self.log.info(u'Регистрация сервиса mobile')
        self.__updateCases()

        servicestub.route('/mobile/client', method='POST', callback=self.client)
        servicestub.route('/mobile/client/balance', method='POST', callback=self.balance)
        servicestub.route('/mobile/client/modify', method='POST', callback=self.modify)
        servicestub.route('/mobile/client/registration', method='POST', callback=self.clientRegistration)

        servicestub.route('/mobile/feed', method='POST', callback=self.feed)
        servicestub.route('/mobile/api/images/<filename:path>', method='GET', name='static', callback=self.image)

        servicestub.route('/mobile/bonushistory', method='POST', callback=self.bonusHistory)
        servicestub.route('/mobile/purchasehistory', method='POST', callback=self.purchaseHistory)
        servicestub.route('/mobile/check', method='POST', callback=self.check)

        servicestub.route('/mobile/verification/request', method='POST', callback=self.verificationRequest)
        servicestub.route('/mobile/verification/verify', method='POST', callback=self.verificationVerify)

    def client(self):
        self.__updateCases()
        params = bottle.request.params
        self.log.info(u'Запрос списка карт по номеру телефона ' + params.phone)
        methodPath = "/mobile/client/" + params.phone
        return self.__getResult(methodPath)

    def balance(self):
        self.__updateCases()
        self.log.info(u'Запрос расширенного баланса по карте')

        return self.__getResult("/mobile/client/balance")
    
    def modify(self):
        self.__updateCases()
        self.log.info(u'Запрос расширенного баланса по карте')

        return self.__getResult("/mobile/client/modify")

    def clientRegistration(self):
        self.__updateCases()
        params = bottle.request.params
        self.log.info(u'Регистарция клиента')
        return self.__getResult("/mobile/client/registration")

    def feed(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Получение ленты для номера ' + params.phone)

        return self.__getResult("/mobile/feed")

    def bonusHistory(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Получение истории бонусных операций')

        return self.__getResult("/mobile/bonushistory")

    def purchaseHistory(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Получение истории покупок')

        return self.__getResult("/mobile/purchasehistory")

    def check(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Получение чека')

        return self.__getResult("/mobile/check")

    def image(self, filename):
        self.log.info(u'Изображение %s', filename)
        time.sleep(random.random())
        return bottle.static_file(filename, root=os.path.join(os.path.dirname(os.path.abspath(__file__)), 'images'))

    def verificationRequest(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Запрос кода подтверждения для телефона ' + params.phone)

        return self.__getResult('/mobile/verification/request')

    def verificationVerify(self):
        self.__updateCases()
        params = bottle.request.params

        self.log.info(u'Проверка кода ' + params.code + u' для телефона ' + params.phone)

        return self.__getResult('/mobile/verification/verify')

    def __getResult(self, methodPath):
        if methodPath not in self.cases:
            raise bottle.HTTPError(400, u'Путь "%s" не существует' % methodPath)

        time.sleep(self.cases[methodPath].get('timeout', 0))

        responseIndex = self.cases[methodPath].get('responseIndex', '')

        body = json.dumps(self.cases[methodPath].get('response' + responseIndex))
        response = bottle.HTTPResponse(status=200, body=body)
        response.add_header("Content-Type", "application/json")

        return response

    def __updateCases(self):
        try:
            for file in "mobile", "verify", "feed", "purchasehistory", "bonushistory", "check", "registration":
                with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), file + '.json'), 'r') as cases:
                    self.cases.update(json.load(cases, encoding='utf-8'))
        except Exception as e:
            self.log.error(str(e))


instance = Mobile()
