#!/usr/bin/python
# -*- coding: utf-8 -*-
import time

from logger import Logger
from singleton import Singleton
import bottle
import json
import os


class Onlineinitialization:
    __metaclass__ = Singleton

    def __init__(self):
        self.log = Logger()
        self.cases = {}

    def registerRoutes(self, servicestub):
        self.log.info(u'Регистрация сервиса получения данных с кассового сервера при первой инициализации кассы')
        self.__updateCases()

        servicestub.route('/CSrest/rest/v2/cashes/initialization', method='POST', callback=self.initialization)

    def initialization(self):

        self.log.info(u'Получение данных с кассового сервера')

        body = json.loads(bottle.request.body.read())
        self.log.info(u"Данные запроса '%s'" % str(body))

        methodName = "/initialization"
        if methodName not in self.cases:
            raise bottle.HTTPError(400, u'Метод "%s" не найден' % methodName)

        if not len(self.cases[methodName]):
            self.log.warn('В кейсах не осталось значений')
            return None

        time.sleep(self.cases[methodName][0].get('timeout', 0))

        # если в кейсе нет счётчика, то возвращаем str(response)
        if 'count' not in self.cases[methodName][0]:
            return json.dumps(self.cases[methodName][0].get('response'))

        self.cases[methodName][0]['count'] -= 1
        response = json.dumps(self.cases[methodName][0].get('response'))

        response = bottle.HTTPResponse(status=self.cases[methodName][0]['status'], body=response)
        if self.cases[methodName][0]['count'] == 0:
            del self.cases[methodName][0]

        return response

    def __updateCases(self):
        try:
            with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'cases.json'), 'r') as cases:
                self.cases = json.load(cases, encoding='utf-8')
        except Exception as e:
            self.log.error(str(e))


instance = Onlineinitialization()
