#!/usr/bin/python
# -*- coding: utf-8 -*-
import random
import time

from logger import Logger
from singleton import Singleton
import bottle
import json
import os


class RaiffeisenSbp:
    __metaclass__ = Singleton

    def __init__(self):
        self.log = Logger()
        self.cases = {}

    def registerRoutes(self, servicestub):
        self.log.info(u'Регистрация сервиса RaiffeisenSbp')
        self.__updateCases()

        servicestub.route('/payment/v1/orders', method='POST', callback=self.orders)
        servicestub.route('/payment/v1/orders/<orderId>', method='GET', callback=self.ordersStatus)
        servicestub.route('/payments/v1/orders/<orderId>/refunds/<refundId>', method='POST', callback=self.refunds)
        servicestub.route('/payments/v1/orders/<orderId>/refunds/<refundId>', method='GET', callback=self.refundsStatus)

    def orders(self):
        self.log.info(u"Регистрация заказа")
        self.__updateCases()
        return self.__getResult('/payment/v1/orders')

    def ordersStatus(self, orderId=''):
        self.log.info(u"Получение статуса заказа")
        self.__updateCases()
        return self.__getResult('/payment/v1/orders/statuses')

    def refunds(self, orderId='', refundId=''):
        self.log.info(u"Отмена заказа")
        self.__updateCases()
        return self.__getResult('/payment/v1/orders/refunds')

    def refundsStatus(self, orderId='', refundId=''):
        self.log.info(u"Получение статуса отмены")
        self.__updateCases()
        return self.__getResult('/payment/v1/orders/refundsStatuses')

    def __getResult(self, methodPath):
        if methodPath not in self.cases:
            raise bottle.HTTPError(400, u'Путь "%s" не существует' % methodPath)

        time.sleep(self.cases[methodPath].get('timeout', 0))

        responseSuffix = self.cases[methodPath].get('responseSuffix', '')

        body = json.dumps(self.cases[methodPath].get('response' + responseSuffix))
        response = bottle.HTTPResponse(status=200, body=body)
        response.add_header("Content-Type", "application/json")

        return response

    def __updateCases(self):
        self.cases.clear()
        try:
            for file in ["raiffeisensbp"]:
                with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), file + '.json'), 'r') as cases:
                    self.cases.update(json.load(cases, encoding='utf-8'))
        except Exception as e:
            self.log.error(str(e))


instance = RaiffeisenSbp()
