#!/usr/bin/python
# -*- coding: utf-8 -*-
import time

from logger import Logger
from singleton import Singleton
import bottle
import json
import os


class Verification:
    __metaclass__ = Singleton

    def __init__(self):
        self.log = Logger()
        self.cases = {}

    def registerRoutes(self, servicestub):
        self.log.info(u'Регистрация сервиса')
        self.__updateCases()

        servicestub.route('/CSrest/rest/ident/cards', method='GET', callback=self.verification)

    def verification(self):
        self.__updateCases()

        params = dict(bottle.request.query.decode())
        cardNumber = params.get('number', '')
        cardGroupId = params.get('idcardgroup', 0)

        self.log.info(u"Верификация карты: '%s'" % cardNumber)
        methodPath = '/CSrest/rest/ident/cards'

        return self.__getResult(methodPath)

    def __getResult(self, methodPath):
        if methodPath not in self.cases:
            raise bottle.HTTPError(400, u'Путь "%s" не существует' % methodPath)

        time.sleep(self.cases[methodPath][0].get('timeout', 0))

        body = json.dumps(self.cases[methodPath][0].get('response'))
        response = bottle.HTTPResponse(status=200, body=body)
        response.add_header("Content-Type", "application/json")

        return response

    def __updateCases(self):
        try:
            with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'verification.json'), 'r') as cases:
                self.cases = json.load(cases, encoding='utf-8')
        except Exception as e:
            self.log.error(str(e))


instance = Verification()
